@@ -11,25 +11,29 @@ use strict;
 use warnings;
 
 package WWW::DaysOfWonder::Memoir44::Utils;
-BEGIN {
-  $WWW::DaysOfWonder::Memoir44::Utils::VERSION = '2.110310';
+{
+  $WWW::DaysOfWonder::Memoir44::Utils::VERSION = '2.120510';
 }
 # ABSTRACT: various subs and constants used in the dist
 
+use Encode;
+use Exporter::Lite;
 use File::HomeDir::PathClass;
-use Sub::Exporter -setup => {
-    exports => [ qw{ DATADIR } ],
-};
+use Locale::TextDomain          'WWW-DaysOfWonder-Memoir44';
 
+our @EXPORT_OK = qw{ $DATADIR T };
+
+
+# -- public vars
+
+our $DATADIR = File::HomeDir::PathClass->my_dist_data(
+        'WWW-DaysOfWonder-Memoir44', { create => 1 } );
 
 
 # -- public subs
 
 
-sub DATADIR {
-    return File::HomeDir::PathClass->my_dist_data(
-        'WWW-DaysOfWonder-Memoir44', { create => 1 } );
-}
+sub T { return decode('utf8', __($_[0])); }
 
 
 1;
@@ -43,24 +47,36 @@ WWW::DaysOfWonder::Memoir44::Utils - various subs and constants used in the dist
 
 =head1 VERSION
 
-version 2.110310
+version 2.120510
 
 =head1 DESCRIPTION
 
-This module exports various subs used in the dist.
+This module exports some subs & variables used in the dist.
+
+The following variables are available:
+
+=over 4
+
+=item * $DATADIR
+
+    my $file = $DATADIR->file( ... );
+
+A L<Path::Class> object containing the data directory for the
+distribution. This directory will be created if needed.
+
+=back
 
 =head1 METHODS
 
-=head2 DATADIR
+=head2 my $locstr = T( $string )
 
-    my $file = DATADIR->file( ... );
-
-Return a L<Path::Class> object containing the data directory for the
-distribution. The directory will be created if needed.
+Performs a call to C<gettext> on C<$string>, convert it from utf8 and
+return the result. Note that i18n is using C<Locale::TextDomain>
+underneath, so refer to this module for more information.
 
 =head1 AUTHOR
 
-  Jerome Quelin
+Jerome Quelin
 
 =head1 COPYRIGHT AND LICENSE
 
